<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
  <context>
    <name>ConfigDialog</name>
    <message>
      <location filename="../config.py" line="86" />
      <source>Using configuration file at:</source>
      <translation>Nutze Konfigurationsdatei aus folgendem Verzeichnis:</translation>
    </message>
    <message>
      <location filename="../config.py" line="105" />
      <source>Behavior</source>
      <translation>Verhalten</translation>
    </message>
    <message>
      <location filename="../config.py" line="106" />
      <source>Automatically save documents</source>
      <translation>Dokumente automatisch speichern</translation>
    </message>
    <message>
      <location filename="../config.py" line="107" />
      <source>Automatically open last documents on startup</source>
      <translation>Zuletzt bearbeitete Dokumente automatisch bei Programmstart öffnen</translation>
    </message>
    <message>
      <location filename="../config.py" line="108" />
      <source>Number of recent documents</source>
      <translation>Anzahl zuletzt geöffneter Dokumente</translation>
    </message>
    <message>
      <location filename="../config.py" line="109" />
      <source>Restore window geometry</source>
      <translation>Fenster-Dimensionierung merken</translation>
    </message>
    <message>
      <location filename="../config.py" line="110" />
      <source>Default preview state</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="111" />
      <source>Open external links in ReText window</source>
      <translation>Externe Verweise im ReText-Fenster öffnen</translation>
    </message>
    <message>
      <location filename="../config.py" line="112" />
      <source>Markdown syntax extensions (comma-separated)</source>
      <translation>Erweiterungen für Markdown-Syntax (durch Kommata getrennt)</translation>
    </message>
    <message>
      <location filename="../config.py" line="114" />
      <source>Enable synchronized scrolling for Markdown</source>
      <translation>Aktiviere für Markdown synchrones Scrollen</translation>
    </message>
    <message>
      <location filename="../config.py" line="179" />
      <location filename="../config.py" line="118" />
      <source>Editor</source>
      <translation>Editor</translation>
    </message>
    <message>
      <location filename="../config.py" line="119" />
      <source>Highlight current line</source>
      <translation>Aktuelle Zeile hervorheben</translation>
    </message>
    <message>
      <location filename="../config.py" line="120" />
      <source>Show line numbers</source>
      <translation>Zeilennummern anzeigen</translation>
    </message>
    <message>
      <location filename="../config.py" line="121" />
      <source>Line numbers are relative to current line</source>
      <translation>Zeilennummern verstehen sich relativ zur aktuellen Zeile</translation>
    </message>
    <message>
      <location filename="../config.py" line="122" />
      <source>Tab key inserts spaces</source>
      <translation>Tabulator fügt Leerzeichen ein</translation>
    </message>
    <message>
      <location filename="../config.py" line="123" />
      <source>Tabulation width</source>
      <translation>Tabulator-Breite</translation>
    </message>
    <message>
      <location filename="../config.py" line="124" />
      <source>Draw vertical line at column</source>
      <translation>Zeichne vertikale Linie in Spalte</translation>
    </message>
    <message>
      <location filename="../config.py" line="125" />
      <source>Enable soft wrap</source>
      <translation>Flexiblen Zeilenumbruch aktivieren. Der Umbruch richtet sich hierbei nach der Fenstergröße und nicht nach Steuerzeichen im Text.</translation>
    </message>
    <message>
      <location filename="../config.py" line="126" />
      <source>Show document stats</source>
      <translation>Statistiken zum Dokument anzeigen.</translation>
    </message>
    <message>
      <location filename="../config.py" line="127" />
      <source>Ordered list mode</source>
      <translation>Aufzählungsmodus</translation>
    </message>
    <message>
      <location filename="../config.py" line="129" />
      <source>Interface</source>
      <translation>Oberfläche</translation>
    </message>
    <message>
      <location filename="../config.py" line="130" />
      <source>Hide toolbar</source>
      <translation>Werkzeugleiste verstecken</translation>
    </message>
    <message>
      <location filename="../config.py" line="131" />
      <source>Icon theme name</source>
      <translation>Symbolschema-Name</translation>
    </message>
    <message>
      <location filename="../config.py" line="132" />
      <source>Stylesheet file</source>
      <translation>Stilvorlage-Datei</translation>
    </message>
    <message>
      <location filename="../config.py" line="133" />
      <source>Hide tabs bar when there is only one tab</source>
      <translation>Reisterleiste verbergen wenn nur ein Reiter offen ist</translation>
    </message>
    <message>
      <location filename="../config.py" line="134" />
      <source>Show full path in window title</source>
      <translation>Kompletten Pfad im Fenstertitel anzeigen</translation>
    </message>
    <message>
      <location filename="../config.py" line="135" />
      <source>Show directory tree</source>
      <translation>Verzeichnisbaum anzeigen</translation>
    </message>
    <message>
      <location filename="../config.py" line="136" />
      <source>Working directory</source>
      <translation>Arbeitsverzeichnis</translation>
    </message>
    <message>
      <location filename="../config.py" line="161" />
      <source>Help</source>
      <translation>Hilfe</translation>
    </message>
    <message>
      <location filename="../config.py" line="180" />
      <source>Live preview</source>
      <translation>Live-Vorschau</translation>
    </message>
    <message>
      <location filename="../config.py" line="181" />
      <source>Normal preview</source>
      <translation>Normale Vorschau</translation>
    </message>
    <message>
      <location filename="../config.py" line="186" />
      <source>Disabled</source>
      <translation>Deaktiviert</translation>
    </message>
    <message>
      <location filename="../config.py" line="187" />
      <source>Cursor Line</source>
      <translation>Cursor-Zeile</translation>
    </message>
    <message>
      <location filename="../config.py" line="188" />
      <source>Wrapped Line</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="193" />
      <source>Increment</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../config.py" line="194" />
      <source>Repeat</source>
      <translation type="unfinished" />
    </message>
  </context>
  <context>
    <name>DirectorySelectButton</name>
    <message>
      <location filename="../config.py" line="61" />
      <source>Select directory to open</source>
      <translation>Zu öffnendes Verzeichnis auswählen</translation>
    </message>
  </context>
  <context>
    <name>EncodingDialog</name>
    <message>
      <location filename="../dialogs.py" line="63" />
      <source>Enter encoding name:</source>
      <translation type="unfinished" />
    </message>
  </context>
  <context>
    <name>FileDialogButton</name>
    <message>
      <location filename="../config.py" line="35" />
      <source>(none)</source>
      <translation>(keine)</translation>
    </message>
  </context>
  <context>
    <name>FileSelectButton</name>
    <message>
      <location filename="../config.py" line="53" />
      <source>Select file to open</source>
      <translation>Zu öffnende Datei auswählen</translation>
    </message>
  </context>
  <context>
    <name>InsertTableDialog</name>
    <message>
      <location filename="../tabledialog.py" line="27" />
      <source>Insert table</source>
      <translation>Tabelle einfügen</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="36" />
      <source>Number of rows</source>
      <translation>Anzahl Zeilen</translation>
    </message>
    <message>
      <location filename="../tabledialog.py" line="37" />
      <source>Number of columns</source>
      <translation>Anzahl Spalten</translation>
    </message>
  </context>
  <context>
    <name>LocaleDialog</name>
    <message>
      <location filename="../dialogs.py" line="43" />
      <source>Enter locale name (example: en_US)</source>
      <translation>Eingabe der Lokalisierung (z.B.: de_DE)</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="44" />
      <source>It is possible to specify multiple languages, separated by comma.</source>
      <translation>Es können mehrere Sprachen durch Komma getrennt angegeben werden.</translation>
    </message>
    <message>
      <location filename="../dialogs.py" line="50" />
      <source>Set as default</source>
      <translation>Als Standard setzen</translation>
    </message>
  </context>
  <context>
    <name>Proxy</name>
    <message>
      <location filename="../fakevimeditor.py" line="62" />
      <source>No write since last change (add ! to override)</source>
      <translation>Nichts geschrieben seit der letzten Änderung (! zum Überschreiben)</translation>
    </message>
    <message>
      <location filename="../fakevimeditor.py" line="118" />
      <source>Information</source>
      <translation>Information</translation>
    </message>
  </context>
  <context>
    <name>ReTextEdit</name>
    <message>
      <location filename="../editor.py" line="252" />
      <source>Add to dictionary</source>
      <translation>Zum Wörterbuch hinzufügen.</translation>
    </message>
    <message>
      <location filename="../editor.py" line="464" />
      <source>Save image</source>
      <translation>Als Bild speichern</translation>
    </message>
    <message>
      <location filename="../editor.py" line="466" />
      <source>Images (*.png *.jpg)</source>
      <translation>Bild (*.png *.jpg)</translation>
    </message>
  </context>
  <context>
    <name>ReTextTab</name>
    <message>
      <location filename="../tab.py" line="174" />
      <source>New document</source>
      <translation>Neues Dokument</translation>
    </message>
    <message>
      <location filename="../tab.py" line="179" />
      <source>Could not parse file contents, check if you have the &lt;a href="%s"&gt;necessary module&lt;/a&gt; installed!</source>
      <translation>Konnte den Dateiinhalt nicht parsen. Überprüfen Sie, ob das &lt;a href="%s"&gt;benötigte Modul&lt;/a&gt; installiert ist!</translation>
    </message>
    <message>
      <location filename="../tab.py" line="487" />
      <source>Create missing file?</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../tab.py" line="488" />
      <source>The file '%s' does not exist.

Do you want to create it?</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../tab.py" line="520" />
      <source>File could not be created</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../tab.py" line="521" />
      <source>Could not create file '%s': %s</source>
      <translation type="unfinished" />
    </message>
  </context>
  <context>
    <name>ReTextWindow</name>
    <message>
      <location filename="../window.py" line="91" />
      <source>File toolbar</source>
      <translation>Werkzeugleiste 'Datei'</translation>
    </message>
    <message>
      <location filename="../window.py" line="93" />
      <source>Edit toolbar</source>
      <translation>Werkzeugleiste 'Bearbeiten'</translation>
    </message>
    <message>
      <location filename="../window.py" line="95" />
      <source>Search toolbar</source>
      <translation>Werkzeugleiste 'Suchen'</translation>
    </message>
    <message>
      <location filename="../window.py" line="99" />
      <source>New</source>
      <translation>Neu</translation>
    </message>
    <message>
      <location filename="../window.py" line="101" />
      <source>Open</source>
      <translation>Öffnen</translation>
    </message>
    <message>
      <location filename="../window.py" line="103" />
      <source>Set encoding</source>
      <translation>Zeichenkodierung festlegen</translation>
    </message>
    <message>
      <location filename="../window.py" line="1187" />
      <location filename="../window.py" line="106" />
      <source>Reload</source>
      <translation>Neu laden</translation>
    </message>
    <message>
      <location filename="../window.py" line="109" />
      <source>Save</source>
      <translation>Speichern</translation>
    </message>
    <message>
      <location filename="../window.py" line="112" />
      <source>Save as</source>
      <translation>Speichern unter</translation>
    </message>
    <message>
      <location filename="../window.py" line="114" />
      <source>Next tab</source>
      <translation>Nächster Reiter</translation>
    </message>
    <message>
      <location filename="../window.py" line="116" />
      <source>Previous tab</source>
      <translation>Voriger Reiter</translation>
    </message>
    <message>
      <location filename="../window.py" line="118" />
      <source>Close tab</source>
      <translation>Reiter schließen</translation>
    </message>
    <message>
      <location filename="../window.py" line="120" />
      <source>Print</source>
      <translation>Drucken</translation>
    </message>
    <message>
      <location filename="../window.py" line="122" />
      <source>Print preview</source>
      <translation>Druckvorschau</translation>
    </message>
    <message>
      <location filename="../window.py" line="124" />
      <source>View HTML code</source>
      <translation>HTML-Code anzeigen</translation>
    </message>
    <message>
      <location filename="../window.py" line="125" />
      <source>Change editor font</source>
      <translation>Schriftart des Editors ändern</translation>
    </message>
    <message>
      <location filename="../window.py" line="127" />
      <source>Change preview font</source>
      <translation>Schriftart der Vorschau ändern</translation>
    </message>
    <message>
      <location filename="../window.py" line="129" />
      <source>Find text</source>
      <translation>Suche</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <location filename="../window.py" line="131" />
      <source>Go to line</source>
      <translation>Zur Zeile springen</translation>
    </message>
    <message>
      <location filename="../window.py" line="134" />
      <source>Preview</source>
      <translation>Vorschau</translation>
    </message>
    <message>
      <location filename="../window.py" line="144" />
      <source>Live preview</source>
      <translation>Live-Vorschau</translation>
    </message>
    <message>
      <location filename="../window.py" line="148" />
      <source>Insert table</source>
      <translation>Tabelle einfügen</translation>
    </message>
    <message>
      <location filename="../window.py" line="150" />
      <source>Table editing mode</source>
      <translation>Tabellenbearbeitungsmodus</translation>
    </message>
    <message>
      <location filename="../window.py" line="153" />
      <source>Insert images by file path</source>
      <translation>Bilder nach Pfad einfügen</translation>
    </message>
    <message>
      <location filename="../window.py" line="156" />
      <source>FakeVim mode</source>
      <translation>Pseudo-Vim-Modus</translation>
    </message>
    <message>
      <location filename="../window.py" line="161" />
      <source>Fullscreen mode</source>
      <translation>Vollbildmodus</translation>
    </message>
    <message>
      <location filename="../window.py" line="649" />
      <location filename="../window.py" line="164" />
      <source>Preferences</source>
      <translation>Einstellungen</translation>
    </message>
    <message>
      <location filename="../window.py" line="171" />
      <source>Quit</source>
      <translation>Beenden</translation>
    </message>
    <message>
      <location filename="../window.py" line="174" />
      <source>Undo</source>
      <translation>Rückgängig</translation>
    </message>
    <message>
      <location filename="../window.py" line="176" />
      <source>Redo</source>
      <translation>Wiederholen</translation>
    </message>
    <message>
      <location filename="../window.py" line="178" />
      <source>Copy</source>
      <translation>Kopieren</translation>
    </message>
    <message>
      <location filename="../window.py" line="180" />
      <source>Cut</source>
      <translation>Ausschneiden</translation>
    </message>
    <message>
      <location filename="../window.py" line="182" />
      <source>Paste</source>
      <translation>Einfügen</translation>
    </message>
    <message>
      <location filename="../window.py" line="184" />
      <source>Paste image</source>
      <translation>Bild einfügen</translation>
    </message>
    <message>
      <location filename="../window.py" line="186" />
      <source>Move line up</source>
      <translation>Zeile nach oben verschieben</translation>
    </message>
    <message>
      <location filename="../window.py" line="188" />
      <source>Move line down</source>
      <translation>Zeile nach unten verschieben</translation>
    </message>
    <message>
      <location filename="../window.py" line="196" />
      <source>Enable</source>
      <translation>Aktivieren</translation>
    </message>
    <message>
      <location filename="../window.py" line="197" />
      <source>Set locale</source>
      <translation>Spracheinstellung</translation>
    </message>
    <message>
      <location filename="../window.py" line="198" />
      <source>Use WebEngine (Chromium) renderer</source>
      <translation>WebEngine (Chromium) Renderer benutzen</translation>
    </message>
    <message>
      <location filename="../window.py" line="204" />
      <source>Show directory</source>
      <translation>Verzeichnis anzeigen</translation>
    </message>
    <message>
      <location filename="../window.py" line="205" />
      <source>Next</source>
      <translation>Weiter</translation>
    </message>
    <message>
      <location filename="../window.py" line="207" />
      <source>Previous</source>
      <translation>Zurück</translation>
    </message>
    <message>
      <location filename="../window.py" line="209" />
      <source>Replace</source>
      <translation>Ersetzen</translation>
    </message>
    <message>
      <location filename="../window.py" line="211" />
      <source>Replace all</source>
      <translation>Alle ersetzen</translation>
    </message>
    <message>
      <location filename="../window.py" line="214" />
      <source>Close</source>
      <translation>Schließen</translation>
    </message>
    <message>
      <location filename="../window.py" line="218" />
      <source>Get help online</source>
      <translation>Online Hilfe bekommen</translation>
    </message>
    <message>
      <location filename="../window.py" line="219" />
      <source>What's new</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../window.py" line="220" />
      <source>About ReText</source>
      <translation>Über ReText</translation>
    </message>
    <message>
      <location filename="../window.py" line="223" />
      <source>About Qt</source>
      <translation>Über Qt</translation>
    </message>
    <message>
      <location filename="../window.py" line="238" />
      <source>Bold</source>
      <translation>Fett</translation>
    </message>
    <message>
      <location filename="../window.py" line="240" />
      <source>Italic</source>
      <translation>Kursiv</translation>
    </message>
    <message>
      <location filename="../window.py" line="242" />
      <source>Underline</source>
      <translation>Unterstrichen</translation>
    </message>
    <message>
      <location filename="../window.py" line="315" />
      <location filename="../window.py" line="251" />
      <source>Formatting</source>
      <translation>Formatieren</translation>
    </message>
    <message>
      <location filename="../window.py" line="255" />
      <source>Symbols</source>
      <translation>Symbole</translation>
    </message>
    <message>
      <location filename="../window.py" line="260" />
      <source>&amp;File</source>
      <translation>&amp;Datei</translation>
    </message>
    <message>
      <location filename="../window.py" line="261" />
      <source>&amp;Edit</source>
      <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
      <location filename="../window.py" line="262" />
      <source>&amp;Help</source>
      <translation>&amp;Hilfe</translation>
    </message>
    <message>
      <location filename="../window.py" line="265" />
      <source>Open recent</source>
      <translation>Zuletzt geöffnet</translation>
    </message>
    <message>
      <location filename="../window.py" line="278" />
      <source>Export</source>
      <translation>Exportieren</translation>
    </message>
    <message>
      <location filename="../window.py" line="303" />
      <source>Spell check</source>
      <translation>Rechtschreibprüfung</translation>
    </message>
    <message>
      <location filename="../window.py" line="312" />
      <source>Default markup</source>
      <translation>Standard-Markup</translation>
    </message>
    <message>
      <location filename="../window.py" line="360" />
      <source>Search</source>
      <translation>Suchen</translation>
    </message>
    <message>
      <location filename="../window.py" line="363" />
      <source>Replace with</source>
      <translation>Ersetzen durch</translation>
    </message>
    <message>
      <location filename="../window.py" line="365" />
      <source>Case sensitively</source>
      <translation>Groß-/Kleinschreibung</translation>
    </message>
    <message>
      <location filename="../window.py" line="552" />
      <location filename="../window.py" line="506" />
      <source>New document</source>
      <translation>Neues Dokument</translation>
    </message>
    <message>
      <location filename="../window.py" line="701" />
      <source>Type the line number</source>
      <translation>Zeilennummer eingeben</translation>
    </message>
    <message>
      <location filename="../window.py" line="737" />
      <source>Please, save the file somewhere.</source>
      <translation>Bitte die Datei irgendwo speichern.</translation>
    </message>
    <message>
      <location filename="../window.py" line="856" />
      <source>Select one or several files to open</source>
      <translation>Eine oder mehrere Dateien zum Öffnen auswählen</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>Supported files</source>
      <translation>Unterstützte Dateien</translation>
    </message>
    <message>
      <location filename="../window.py" line="1244" />
      <location filename="../window.py" line="857" />
      <source>All files (*)</source>
      <translation>Alle Dateien (*)</translation>
    </message>
    <message>
      <location filename="../window.py" line="912" />
      <source>Plain text (*.txt)</source>
      <translation>Klartext (*.txt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="915" />
      <source>%s files</source>
      <comment>Example of final string: Markdown files</comment>
      <translation>%s-Dateien</translation>
    </message>
    <message>
      <location filename="../window.py" line="984" />
      <location filename="../window.py" line="928" />
      <source>Save file</source>
      <translation>Datei speichern</translation>
    </message>
    <message>
      <location filename="../window.py" line="936" />
      <source>Cannot save to file which is open in another tab!</source>
      <translation>Speichern in eine Datei, die in einem anderen Tab geöffnet ist, ist nicht möglich!</translation>
    </message>
    <message>
      <location filename="../window.py" line="974" />
      <source>Export document to ODT</source>
      <translation>Dokument als ODT exportieren</translation>
    </message>
    <message>
      <location filename="../window.py" line="975" />
      <source>OpenDocument text files (*.odt)</source>
      <translation>OpenDocument-Dateien (*.odt)</translation>
    </message>
    <message>
      <location filename="../window.py" line="985" />
      <source>HTML files (*.html *.htm)</source>
      <translation>HTML-Dateien (*.html *.htm)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1005" />
      <source>Unrecognized paperSize setting "%s".</source>
      <translation>Unerkannte paperSize Einstellung »%s«.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1020" />
      <source>Export document to PDF</source>
      <translation>Dokument als PDF exportieren</translation>
    </message>
    <message>
      <location filename="../window.py" line="1022" />
      <source>PDF files (*.pdf)</source>
      <translation>PDF-Dateien (*.pdf)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1046" />
      <source>Print document</source>
      <translation>Dokument drucken</translation>
    </message>
    <message>
      <location filename="../window.py" line="1070" />
      <source>Export document</source>
      <translation>Dokument exportieren</translation>
    </message>
    <message>
      <location filename="../window.py" line="1090" />
      <source>Failed to execute the command:</source>
      <translation>Ausführung des Befehls fehlgeschlagen:</translation>
    </message>
    <message>
      <location filename="../window.py" line="1126" />
      <source>Alt text</source>
      <translation>Alt-Text</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <location filename="../window.py" line="1126" />
      <source>URL</source>
      <translation>URL</translation>
    </message>
    <message>
      <location filename="../window.py" line="1127" />
      <source>Link text</source>
      <translation>Linktext</translation>
    </message>
    <message>
      <location filename="../window.py" line="1168" />
      <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
      <translation>Diese Datei wurde durch eine andere Anwendung gelöscht.
Bitte sichern Sie die Datei vor dem Beenden.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1177" />
      <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
      <translation>Dieses Dokument wurde durch eine andere Anwendung geändert.
Wollen Sie die Datei neu laden (wobei alle Ihre Änderungen
verworfen werden)?</translation>
    </message>
    <message>
      <location filename="../window.py" line="1182" />
      <source>Automatic saving has been temporarily disabled for this tab to prevent data loss. It will be re-enabled when you reload the file or save it manually.</source>
      <translation>Automatisches Speichern für diesen Reiter wurde vorübergehend deaktiviert um Datenverlust zu verhindern. Es wird reaktiviert wenn Sie die Datei neu laden oder manuell speichern.</translation>
    </message>
    <message>
      <location filename="../window.py" line="1205" />
      <source>The document has been modified.
Do you want to save your changes?</source>
      <translation>Das Dokument wurde verändert.
Möchten Sie Ihre Änderungen speichern ?</translation>
    </message>
    <message>
      <location filename="../window.py" line="1232" />
      <source>HTML code</source>
      <translation>HTML-Code</translation>
    </message>
    <message>
      <location filename="../window.py" line="1243" />
      <source>Select one or several images to open</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../window.py" line="1264" />
      <source>ReText %s (using PyMarkups %s)</source>
      <translation>ReText %s (mit PyMarkups %s)</translation>
    </message>
    <message>
      <location filename="../window.py" line="1265" />
      <source>Simple but powerful editor for Markdown and reStructuredText</source>
      <translation>Einfacher aber mächtiger Editor für Markdown and reStructuredText</translation>
    </message>
    <message>
      <location filename="../window.py" line="1267" />
      <source>Author: Dmitry Shachnev, 2011</source>
      <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
      <location filename="../window.py" line="1270" />
      <source>Markdown syntax</source>
      <translation>Markdown-Syntax</translation>
    </message>
    <message>
      <location filename="../window.py" line="1272" />
      <source>reStructuredText syntax</source>
      <translation>reStructuredText-Syntax</translation>
    </message>
  </context>
  <context>
    <name>TextInfoArea</name>
    <message>
      <location filename="../editor.py" line="659" />
      <source>%d w | %d a | %d c</source>
      <comment>count of words, alphanumeric characters, all characters</comment>
      <translation>%d w | %d a | %d c</translation>
    </message>
  </context>
  <context>
    <name>main</name>
    <message>
      <location filename="../__main__.py" line="84" />
      <source>Open the files in preview mode</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../__main__.py" line="86" />
      <source>Create a new window even if there is an existing one</source>
      <translation type="unfinished" />
    </message>
    <message>
      <location filename="../__main__.py" line="90" />
      <source>List of files to open</source>
      <translation type="unfinished" />
    </message>
  </context>
</TS>
